==> snipe-it-5.1.8.zip: snipe-it-5.1.8/resources/lang/fa/admin/hardware/form.php <==
<?php

return array(
	'bulk_delete'		=> 'تأیید دارایی های حذف فله',
  'bulk_delete_help'	=> 'بررسی دارایی برای حذف فله زیر کلیک کنید. به محض حذف این دارایی ها را می توان ترمیم کرد، اما ان ها دیگر قابل دسترسی با یوزر های دیگر نیستند.',
  'bulk_delete_warn'	=> 'شما در حال حذف: دارایی های تعداد دارایی.',
	'bulk_update'		=> 'به روز رسانی دارایی های فله',
	'bulk_update_help'	=> 'این فرم برای به روز رسانی دارایی های متعدد در یک بار را به شما اجازه می دهد. تنها قسمت ها نیاز به تغییر را پر کنید. هر زمینه های خالی سمت چپ بدون تغییر باقی می ماند. ',
	'bulk_update_warn'	=> 'شما در حال ادیت مشخصات : ',
    'checkedout_to'		=> 'تحویل شده به

',
    'checkout_date'		=> 'چک کردن تاریخ
',
    'checkin_date'		=> 'تاریخ ورود
',
    'checkout_to'		=> 'اتمام به
',
    'cost'				=> 'هزینه خرید',
    'create'			=> 'ایجاد دارایی
',
    'date'				=> 'تاریخ خرید
',
    'depreciation'	    => 'استهلاک',
    'depreciates_on'	=> 'مستهلک کردن 
',
    'default_location'	=> ' پیش فرض محل سکونت
',
    'eol_date'			=> ' تاریخ EOL
',
    'eol_rate'			=> ' نرخ EOL',
    'expected_checkin'  => ' چک در تاریخ را پر کنید',
    'expires'			=> 'تاریخ انقضا
',
    'fully_depreciated'	=> 'به طور کامل مستهلک شده',
    'help_checkout'		=> 'اگر شما مایل به اختصاص این دارایی ها هستید بلافاصله، "آماده به استقرار" از لیست وضعیت به بالا انتخاب کنید.',
    'mac_address'		=> 'مک ادرس',
    'manufacturer'		=> 'سازنده',
    'model'				=> 'مدل',
    'months'			=> 'ماه ها',
    'name'				=> 'نام دارایی',
    'notes'				=> 'نت ها',
    'order'				=> 'شماره سفارش',
    'qr'				=> 'کیو آر کد',
    'requestable'		=> 'کاربران ممکن است این دارایی هارا درخواست کنند
',
    'select_statustype'	=> 'انتخاب نوع وضعیت',
    'serial'			=> 'سریال',
    'status'			=> 'وضعیت',
    'tag'				=> 'برچسب دارایی
',
    'update'			=> 'به روز رسانی دارایی
',
    'warranty'			=> 'گارانتی',
		'warranty_expires'		=> 'انقضای ضمانت',
    'years'				=> 'سال ها',
)
;

==> snipe-it-5.4.3.zip: snipe-it-5.4.3/resources/lang/fa/admin/hardware/form.php <==
<?php

return [
    'bulk_delete'		=> 'تأیید دارایی های حذف فله',
  'bulk_delete_help'	=> 'بررسی دارایی برای حذف فله زیر کلیک کنید. به محض حذف این دارایی ها را می توان ترمیم کرد، اما ان ها دیگر قابل دسترسی با یوزر های دیگر نیستند.',
  'bulk_delete_warn'	=> 'شما در حال حذف: دارایی های تعداد دارایی.',
    'bulk_update'		=> 'به روز رسانی دارایی های فله',
    'bulk_update_help'	=> 'این فرم برای به روز رسانی دارایی های متعدد در یک بار را به شما اجازه می دهد. تنها قسمت ها نیاز به تغییر را پر کنید. هر زمینه های خالی سمت چپ بدون تغییر باقی می ماند. ',
    'bulk_update_warn'	=> 'شما در حال ادیت مشخصات : ',
    'checkedout_to'		=> 'تحویل شده به

',
    'checkout_date'		=> 'چک کردن تاریخ
',
    'checkin_date'		=> 'تاریخ ورود
',
    'checkout_to'		=> 'اتمام به
',
    'cost'				=> 'هزینه خرید',
    'create'			=> 'ایجاد دارایی
',
    'date'				=> 'تاریخ خرید
',
    'depreciation'	    => 'استهلاک',
    'depreciates_on'	=> 'مستهلک کردن 
',
    'default_location'	=> ' پیش فرض محل سکونت
',
    'eol_date'			=> ' تاریخ EOL
',
    'eol_rate'			=> ' نرخ EOL',
    'expected_checkin'  => ' چک در تاریخ را پر کنید',
    'expires'			=> 'تاریخ انقضا
',
    'fully_depreciated'	=> 'به طور کامل مستهلک شده',
    'help_checkout'		=> 'اگر شما مایل به اختصاص این دارایی ها هستید بلافاصله، "آماده به استقرار" از لیست وضعیت به بالا انتخاب کنید.',
    'mac_address'		=> 'مک ادرس',
    'manufacturer'		=> 'سازنده',
    'model'				=> 'مدل',
    'months'			=> 'ماه ها',
    'name'				=> 'نام دارایی',
    'notes'				=> 'نت ها',
    'order'				=> 'شماره سفارش',
    'qr'				=> 'کیو آر کد',
    'requestable'		=> 'کاربران ممکن است این دارایی هارا درخواست کنند
',
    'select_statustype'	=> 'انتخاب نوع وضعیت',
    'serial'			=> 'سریال',
    'status'			=> 'وضعیت',
    'tag'				=> 'برچسب دارایی
',
    'update'			=> 'به روز رسانی دارایی
',
    'warranty'			=> 'گارانتی',
        'warranty_expires'		=> 'انقضای ضمانت',
    'years'				=> 'سال ها',
    'asset_location' => 'بروزرسانی مکان دارایی',
    'asset_location_update_default_current' => 'بروزرسانی مکان پیش‌فرض AND مکان فعلی',
    'asset_location_update_default' => 'فقط بروزرسانی مکان پیش‌فرض',
    'asset_not_deployable' => 'این وضعیت دارایی قابل استقرار نیست. این دارایی قابل پذیرش نیست.',
    'asset_deployable' => 'این وضعیت دارایی قابل استقرار است. این دارایی قابل پذیرش است.',
    'processing_spinner' => 'در حال پردازش...',
];
